


class CorrelationTracker(object):
    """
    Track objects based on a correlation tracking algorithm.

    Typical usage::

        obj_detect = edgeiq.ObjectDetection(
                'alwaysai/ssd_mobilenet_v1_coco_2018_01_28')
        obj_detect.load(engine=edgeiq.Engine.DNN)

        tracker = edgeiq.CorrelationTracker(max_objects=5)

        while True:
            <get video frame>

            # Perform detection once every detect_period
            if frame_idx % detect_period:
                results = obj_detect.detect_objects(frame, confidence_level=.5)

                # Stop tracking old objects
                if tracker.count:
                    tracker.stop_all()

                for prediction in results.prediction:
                    tracker.start(frame, prediction)

            else:
                if tracker.count:
                    predictions = tracker.update(frame)

            frame = edgeiq.markup_image(
                        frame, predictions, colors=obj_detect.colors)

    :type max_objects: integer
    :param max_objects: The maximum number of objects to track.
    """
    def __init__(self, max_objects=None):
        pass

    def start(self, image, prediction):
        pass

    @property
    def count(self):
        pass

    def update(self, image):
        pass

    def stop_all(self):
        pass

class CentroidTracker(object):
    """
    Associate a bounding box with an object ID based on distances from
    previous detections.

    Typical usage::

        obj_detect = edgeiq.ObjectDetection(
                'alwaysai/res10_300x300_ssd_iter_140000')
        obj_detect.load(engine=edgeiq.Engine.DNN)

        centroid_tracker = edgeiq.CentroidTracker(
                deregister_frames=20, max_distance=50)

        while True:
            <get video frame>
            results = obj_detect.detect_objects(frame, confidence_level=.5)

            objects = centroid_tracker.update(results.predictions)

            # Use the object dictionary to create a new prediction list
            for (object_id, prediction) in objects.items():
                new_label = 'face {}'.format(object_id)
                prediction.label = new_label
                text.append(new_label)
                predictions.append(prediction)

            frame = edgeiq.markup_image(frame, predictions)

    :type deregister_frames: integer
    :param deregister_frames: The number of frames before deregistering an
                              object that can no longer be found.
    :type max_distance: integer
    :param max_distance: The maximum distance between two centroids to
                         associate an object.
    """
    def __init__(self, deregister_frames=50, max_distance=50):
        pass

    def update(self, predictions):
        pass

